# Metrics Module

Built-in metrics for aggregating evaluation results across your dataset.

## @metric Decorator

Create custom metrics that can be attached to evaluators.

::: dotevals.metrics.base.metric

## Built-in Metrics

### accuracy

Compute accuracy as the mean of boolean scores.

::: dotevals.metrics.base.accuracy

## Types

### Metric Type

::: dotevals.metrics.base.Metric
